@@ -232,7 +232,7 @@ void addMonsterToContiguousMonsterGrid(short x, short y, creature *monst, char g
 	}
 }
 
-// Splits a monster in half; this is different from purely cloning it since it halves its HP.
+// Splits a monster in half.
 // The split occurs only if there is a spot adjacent to the contiguous
 // group of monsters that the monster would not avoid.
 // The contiguous group is supplemented with the given (x, y) coordinates, if any;
@@ -308,13 +308,17 @@ void splitMonster(creature *monst, short x, short y) {
 }
 
 // This function is called whenever one creature acts aggressively against another in a way that causes damage.
-// This can be things like melee attacks, fire/lightning attacks, throwing a weapon.
+// This can be things like melee attacks, fire/lightning attacks or throwing a weapon.
 void moralAttack(creature *attacker, creature *defender) {
 	
 	if (defender->currentHP > 0
 		&& !(defender->bookkeepingFlags & MONST_IS_DYING)) {
 		
-		defender->status[STATUS_PARALYZED] = 0;
+        if (defender->status[STATUS_PARALYZED]) {
+            defender->status[STATUS_PARALYZED] = 0;
+             // Paralyzed creature gets a turn to react before the attacker moves again.
+            defender->ticksUntilTurn = min(attacker->attackSpeed, 100) - 1;
+        }
 		if (defender->status[STATUS_MAGICAL_FEAR]) {
 			defender->status[STATUS_MAGICAL_FEAR] = 1;
 		}
@@ -391,6 +395,7 @@ void specialHit(creature *attacker, creature *defender, short damage) {
 			&& !(attacker->carriedItem)
 			&& (packItems->nextItem)
 			&& attacker->currentHP > 0
+            && monstersAreEnemies(attacker, defender) // No stealing from the player if you bump him while confused.
 			&& attackHit(attacker, defender)) {
 			
 			itemCandidates = numberOfMatchingPackItems(ALL_ITEMS & ~AMULET, 0, (ITEM_EQUIPPED), false);
@@ -440,17 +445,17 @@ void specialHit(creature *attacker, creature *defender, short damage) {
 		defender->maxStatus[STATUS_POISONED] = defender->info.maxHP;
 	}
 	if ((attacker->info.abilityFlags & MA_CAUSES_WEAKNESS) && damage > 0) {
-		weaken(defender, 200);
+		weaken(defender, 300);
 	}
 }
 
 short runicWeaponChance(item *theItem, boolean customEnchantLevel, float enchantLevel) {
 	const float effectChances[NUMBER_WEAPON_RUNIC_KINDS] = {
 		0.2,	// W_SPEED
-		0.09,	// W_QUIETUS
-		0.1,	// W_PARALYSIS
+		0.07,	// W_QUIETUS
+		0.09,	// W_PARALYSIS
 		0.11,	// W_MULTIPLICITY
-		0.12,	// W_SLOWING
+		0.14,	// W_SLOWING
 		0.11,	// W_CONFUSION
 		0,		// W_SLAYING
 		0,		// W_MERCY
@@ -518,7 +523,7 @@ void magicWeaponHit(creature *defender, item *theItem, boolean backstabbed) {
 		chance = (theItem->vorpalEnemy == defender->info.monsterID ? 100 : 0);
 	} else {
 		chance = runicWeaponChance(theItem, false, 0);
-		if (backstabbed) {
+		if (backstabbed && chance < 100) {
 			chance *= 2;
 		}
 	}
@@ -732,6 +737,7 @@ void applyArmorRunicEffect(char returnString[DCOLS], creature *attacker, short *
 							&& monstersAreEnemies(&player, monst)
 							&& !(monst->info.flags & MONST_IMMUNE_TO_WEAPONS)
 							&& !(monst->bookkeepingFlags & MONST_IS_DYING)) {
+                            
 							hitList[i] = monst;
 							count++;
 						}
@@ -743,6 +749,7 @@ void applyArmorRunicEffect(char returnString[DCOLS], creature *attacker, short *
 							monsterName(monstName, hitList[i], true);
 							if (inflictDamage(attacker, hitList[i], (*damage + count) / (count + 1), &blue)
 								&& canSeeMonster(hitList[i])) {
+                                
 								sprintf(buf, "%s %s", monstName, ((hitList[i]->info.flags & MONST_INANIMATE) ? "is destroyed" : "dies"));
 								combatMessage(buf, messageColorFromVictim(hitList[i]));
 							}
@@ -805,6 +812,14 @@ void applyArmorRunicEffect(char returnString[DCOLS], creature *attacker, short *
 				runicDiscovered = true;
 			}
 			break;
+        case A_IMMOLATION:
+            if (rand_percent(10)) {
+                sprintf(returnString, "flames suddenly explode out of your %s!", armorName);
+                message(returnString, !runicKnown);
+                returnString[0] = '\0';
+                spawnDungeonFeature(player.xLoc, player.yLoc, &(dungeonFeatureCatalog[DF_ARMOR_IMMOLATION]), true, false);
+                runicDiscovered = true;
+            }
 		default:
 			break;
 	}
@@ -817,11 +832,27 @@ void applyArmorRunicEffect(char returnString[DCOLS], creature *attacker, short *
 	}
 }
 
+void decrementWeaponAutoIDTimer() {
+    char buf[COLS*2], buf2[COLS*2];
+    
+    if (rogue.weapon
+        && !(rogue.weapon->flags & ITEM_IDENTIFIED)
+        && !--rogue.weapon->charges) {
+        
+        rogue.weapon->flags |= ITEM_IDENTIFIED;
+        updateIdentifiableItems();
+        messageWithColor("you are now familiar enough with your weapon to identify it.", &itemMessageColor, false);
+        itemName(rogue.weapon, buf2, true, true, NULL);
+        sprintf(buf, "%s %s.", (rogue.weapon->quantity > 1 ? "they are" : "it is"), buf2);
+        messageWithColor(buf, &itemMessageColor, false);
+    }
+}
+
 // returns whether the attack hit
 boolean attack(creature *attacker, creature *defender) {
 	short damage, transferenceAmount, poisonDamage;
 	char buf[COLS*2], buf2[COLS*2], attackerName[COLS], defenderName[COLS], verb[DCOLS], explicationClause[DCOLS] = "", armorRunicString[DCOLS*3];
-	boolean sneakAttack, defenderWasAsleep, defenderWasParalyzed, degradesAttackerWeapon, sightUnseen;
+	boolean sneakAttack, defenderWasAsleep, defenderWasParalyzed, degradesAttackerWeapon, sightUnseen, creditWeaponKill;
 	
 	if (attacker->info.abilityFlags & MA_KAMIKAZE) {
 		addExperience(attacker->info.expForKilling);
@@ -832,6 +863,7 @@ boolean attack(creature *attacker, creature *defender) {
 	armorRunicString[0] = '\0';
 	
 	poisonDamage = 0;
+    creditWeaponKill = false;
 	
 	degradesAttackerWeapon = (defender->info.flags & MONST_DEFEND_DEGRADE_WEAPON ? true : false);
 	
@@ -876,11 +908,13 @@ boolean attack(creature *attacker, creature *defender) {
 		damage = (defender->info.flags & MONST_IMMUNE_TO_WEAPONS ? 0 : randClump(attacker->info.damage));
 		
 		if (sneakAttack || defenderWasAsleep || defenderWasParalyzed) {
-			// The defender doesn't hit back this turn because he's still flat-footed.
-			defender->ticksUntilTurn += max(defender->movementSpeed, defender->attackSpeed);
-			if (defender->creatureState != MONSTER_ALLY) {
-				defender->creatureState = MONSTER_TRACKING_SCENT; // Wake up!
-			}
+            if (defender != &player) {
+                // The non-player defender doesn't hit back this turn because it's still flat-footed.
+                defender->ticksUntilTurn += max(defender->movementSpeed, defender->attackSpeed);
+                if (defender->creatureState != MONSTER_ALLY) {
+                    defender->creatureState = MONSTER_TRACKING_SCENT; // Wake up!
+                }
+            }
 			damage *= 3; // Treble damage for sneak attacks!
 		}
 		
@@ -888,7 +922,7 @@ boolean attack(creature *attacker, creature *defender) {
 			damage = max(damage/2, 1); // player takes half damage on depth 1
 		}
 		
-		damage = min(damage, defender->currentHP);
+		damage = min(damage, defender->currentHP); // Can't do more damage to a creature than it has remaining health.
 		
 		if (((attacker == &player && rogue.transference) || (attacker != &player && (attacker->info.abilityFlags & MA_TRANSFERENCE)))
 			&& !(defender->info.flags & MONST_INANIMATE)) {
@@ -898,8 +932,10 @@ boolean attack(creature *attacker, creature *defender) {
 				if (transferenceAmount == 0) {
 					transferenceAmount = ((rogue.transference > 0) ? 1 : -1);
 				}
-			} else {
-				transferenceAmount = damage * 9 / 10; // transference monsters get 90% recovery rate, deal with it
+			} else if (attacker->creatureState == MONSTER_ALLY) {
+                transferenceAmount = damage * 4 / 10; // allies get 40% recovery rate
+            } else {
+				transferenceAmount = damage * 9 / 10; // enemies get 90% recovery rate, deal with it
 			}
 
 			attacker->currentHP += min((attacker->info.maxHP - attacker->currentHP), transferenceAmount);
@@ -963,19 +999,6 @@ boolean attack(creature *attacker, creature *defender) {
 				gameOver(attacker->info.monsterName, false);
 				return true;
 			}
-			if (&player == attacker
-				&& defender->info.expForKilling > 0
-				&& rogue.weapon
-				&& !(rogue.weapon->flags & ITEM_IDENTIFIED)
-				&& !--rogue.weapon->charges) {
-				
-				rogue.weapon->flags |= ITEM_IDENTIFIED;
-				updateIdentifiableItems();
-				messageWithColor("you are now familiar enough with your weapon to identify it.", &itemMessageColor, false);
-				itemName(rogue.weapon, buf2, true, true, NULL);
-				sprintf(buf, "%s %s.", (rogue.weapon->quantity > 1 ? "they are" : "it is"), buf2);
-				messageWithColor(buf, &itemMessageColor, false);
-			}
 		} else { // if the defender survived
 			if (!rogue.blockCombatText && (canSeeMonster(attacker) || canSeeMonster(defender))) {
 				attackVerb(verb, attacker, max(damage - attacker->info.damage.lowerBound, 0) * 100
@@ -993,7 +1016,6 @@ boolean attack(creature *attacker, creature *defender) {
 			if (attacker->info.abilityFlags & SPECIAL_HIT) {
 				specialHit(attacker, defender, (attacker->info.abilityFlags & MA_POISONS) ? poisonDamage : damage);
 			}
-			// moved from here
 			if (armorRunicString[0]) {
 				message(armorRunicString, false);
 				if (rogue.armor && (rogue.armor->flags & ITEM_RUNIC) && rogue.armor->enchant2 == A_BURDEN) {
@@ -1004,9 +1026,16 @@ boolean attack(creature *attacker, creature *defender) {
 		
 		moralAttack(attacker, defender);
 		
-		if (attacker == &player && rogue.weapon && (rogue.weapon->flags & ITEM_RUNIC)) { // moved to here
+		if (attacker == &player && rogue.weapon && (rogue.weapon->flags & ITEM_RUNIC)) {
 			magicWeaponHit(defender, rogue.weapon, sneakAttack || defenderWasAsleep || defenderWasParalyzed);
 		}
+        
+        if (attacker == &player
+            && (defender->bookkeepingFlags & MONST_IS_DYING)
+            && defender->info.expForKilling > 0) {
+            
+            decrementWeaponAutoIDTimer(); // This is primarily for quietus.
+        }
 		
 		if (degradesAttackerWeapon
 			&& attacker == &player
@@ -1068,7 +1097,6 @@ short strLenWithoutEscapes(const char *str) {
 }
 
 void combatMessage(char *theMsg, color *theColor) {
-	short i = 0;
 	char newMsg[COLS * 2];
 	
 	if (theColor == 0) {
@@ -1076,7 +1104,7 @@ void combatMessage(char *theMsg, color *theColor) {
 	}
 	
 	newMsg[0] = '\0';
-	i = encodeMessageColor(newMsg, i, theColor);
+	encodeMessageColor(newMsg, 0, theColor);
 	strcat(newMsg, theMsg);
 	
 	if (strLenWithoutEscapes(combatText) + strLenWithoutEscapes(newMsg) + 3 > DCOLS) {
@@ -1113,7 +1141,7 @@ void flashMonster(creature *monst, const color *theColor, short strength) {
 
 boolean canAbsorb(creature *ally, creature *prey, short **grid) {
 	return (ally->creatureState == MONSTER_ALLY
-			&& ally->absorbsAllowed >= XPXP_NEEDED_FOR_ABSORB
+			&& ally->absorbXPXP >= XPXP_NEEDED_FOR_ABSORB
 			&& (ally->targetCorpseLoc[0] <= 0)
 			&& monstersAreEnemies(ally, prey)
 			&& ((~(ally->info.abilityFlags) & prey->info.abilityFlags & LEARNABLE_ABILITIES)
@@ -1198,7 +1226,9 @@ boolean anyoneWantABite(creature *decedent) {
 #define MIN_FLASH_STRENGTH	50
 
 void inflictLethalDamage(creature *attacker, creature *defender) {
-	inflictDamage(attacker, defender, defender->currentHP + (10 * defender->status[STATUS_SHIELDED]), NULL);
+    defender->status[STATUS_SHIELDED] = 0;
+	//inflictDamage(attacker, defender, defender->currentHP + (10 * defender->status[STATUS_SHIELDED]), NULL);
+    inflictDamage(attacker, defender, defender->currentHP, NULL);
 }
 
 // returns true if this was a killing stroke; does NOT free the pointer, but DOES remove it from the monster chain
@@ -1357,9 +1387,7 @@ void killCreature(creature *decedent, boolean administrativeDeath) {
 		}
 	}
 	decedent->currentHP = 0;
-	//if (decedent->bookkeepingFlags & MONST_LEADER) {
 	demoteMonsterFromLeadership(decedent);
-	//}
 }
 
 // Basically runs a simplified deterministic melee combat simulation against a hypothetical
