@@ -31,7 +31,7 @@
 #define USE_UNICODE
 
 // version string -- no more than 16 bytes:
-#define BROGUE_VERSION_STRING "1.6.2"
+#define BROGUE_VERSION_STRING "1.6.4"
 
 // debug macros -- define DEBUGGING as 1 to enable debugging.
 
@@ -71,6 +71,7 @@
 
 // recording and save filenames
 #define LAST_GAME_PATH			"LastGame.broguesave"
+#define LAST_GAME_NAME          "LastGame"
 #define RECORDING_SUFFIX		".broguerec"
 #define GAME_SUFFIX				".broguesave"
 #define ANNOTATION_SUFFIX		".txt"
@@ -106,6 +107,10 @@
 
 #define AMULET_LEVEL			26			// how deep before the amulet appears
 
+#define MACHINES_FACTOR         1.4         // use this to adjust machine frequency
+
+#define MACHINES_BUFFER_LENGTH  100
+
 #define DEFENSE_FACTOR			0.986		// Each point of armor multiplies enemy attackers' accuracy by this value.
 											// (displayed armor value is 10% of the real value)
 #define WEAPON_ENCHANT_FACTOR	1.065		// Each marginal point of weapon enchantment
@@ -115,6 +120,9 @@
 #define ARMOR_DELAY_TO_AUTO_ID	1000
 #define RING_DELAY_TO_AUTO_ID	1500
 
+#define FALL_DAMAGE_MIN         6
+#define FALL_DAMAGE_MAX         12
+
 #define INPUT_RECORD_BUFFER		1000		// how many bytes of input data to keep in memory before vomiting it to disk
 #define DEFAULT_PLAYBACK_DELAY	50
 
@@ -147,6 +155,8 @@
 //#define FOLIAGE_CHAR	0x03A8 // lower-case psi
 #define FOLIAGE_CHAR	0x2648 // Aries symbol
 #define ALTAR_CHAR		'|'
+#define LEVER_CHAR      '/'
+#define LEVER_PULLED_CHAR '\\'
 #define STATUE_CHAR		0x00df
 #define VENT_CHAR		'='
 
@@ -167,6 +177,7 @@
 #define GEM_CHAR		0x25cf
 #define TOTEM_CHAR		0x26b2
 #define TURRET_CHAR		0x25cf
+#define UNICORN_CHAR    0x00da
 #define KEY_CHAR		'-'
 
 #define UP_ARROW_CHAR		0x2191
@@ -203,8 +214,8 @@
 #define FIRE_CHAR		'^'
 #define GRASS_CHAR		'"'
 #define BRIDGE_CHAR		'='
-#define DESCEND_CHAR		'>'
-#define ASCEND_CHAR			'<'
+#define DESCEND_CHAR	'>'
+#define ASCEND_CHAR		'<'
 #define WALL_CHAR		'#'
 #define DOOR_CHAR		'+'
 #define OPEN_DOOR_CHAR	'\''
@@ -214,6 +225,8 @@
 #define WEB_CHAR		':'
 #define FOLIAGE_CHAR	'&'
 #define ALTAR_CHAR		'|'
+#define LEVER_CHAR      '/'
+#define LEVER_PULLED_CHAR '\\'
 #define STATUE_CHAR		'&'
 #define VENT_CHAR		'='
 
@@ -234,6 +247,7 @@
 #define GEM_CHAR		'+'
 #define TOTEM_CHAR		'0'
 #define TURRET_CHAR		'*'
+#define UNICORN_CHAR    'U'
 #define KEY_CHAR		'-'
 
 #define UP_ARROW_CHAR		'^'
@@ -351,12 +365,18 @@ enum tileType {
 	TORCH_WALL, // wall lit with a torch
 	CRYSTAL_WALL,
 	PORTCULLIS_CLOSED,
-	PORTCULLIS_OPEN,
 	PORTCULLIS_DORMANT,
 	ADD_WOODEN_BARRICADE,
 	WOODEN_BARRICADE,
 	PILOT_LIGHT_DORMANT,
 	PILOT_LIGHT,
+    HAUNTED_TORCH_DORMANT,
+    HAUNTED_TORCH_TRANSITIONING,
+    HAUNTED_TORCH,
+    WALL_LEVER_HIDDEN,
+    WALL_LEVER,
+    WALL_LEVER_PULLED,
+    WALL_LEVER_HIDDEN_DORMANT,
 	STATUE_INERT,
 	STATUE_DORMANT,
 	STATUE_CRACKING,
@@ -386,6 +406,8 @@ enum tileType {
 	TRAP_DOOR,
 	GAS_TRAP_PARALYSIS_HIDDEN,
 	GAS_TRAP_PARALYSIS,
+    MACHINE_PARALYSIS_VENT_HIDDEN,
+    MACHINE_PARALYSIS_VENT,
 	GAS_TRAP_CONFUSION_HIDDEN,
 	GAS_TRAP_CONFUSION,
 	FLAMETHROWER_HIDDEN,
@@ -400,6 +422,8 @@ enum tileType {
 	MACHINE_METHANE_VENT,
 	STEAM_VENT,
 	MACHINE_PRESSURE_PLATE,
+    MACHINE_GLYPH,
+    MACHINE_GLYPH_INACTIVE,
 	
 	DEEP_WATER,
 	SHALLOW_WATER,
@@ -408,7 +432,6 @@ enum tileType {
 	CHASM_EDGE,
 	MACHINE_COLLAPSE_EDGE_DORMANT,
 	MACHINE_COLLAPSE_EDGE_SPREADING,
-	CHASM_WITH_HIDDEN_BRIDGE,
 	LAVA,
 	LAVA_RETRACTABLE,
 	LAVA_RETRACTING,
@@ -423,8 +446,9 @@ enum tileType {
 	MACHINE_FLOOD_WATER_DORMANT,
 	MACHINE_FLOOD_WATER_SPREADING,
 	MACHINE_MUD_DORMANT,
-		
+    
 	HOLE,
+	HOLE_GLOW,
 	HOLE_EDGE,
 	FLOOD_WATER_DEEP,
 	FLOOD_WATER_SHALLOW,
@@ -466,6 +490,7 @@ enum tileType {
 	MANACLE_L,
 	MANACLE_R,
 	PORTAL_LIGHT,
+    GUARDIAN_GLOW,
 	
 	PLAIN_FIRE,
 	BRIMSTONE_FIRE,
@@ -480,6 +505,15 @@ enum tileType {
 	METHANE_GAS,
 	STEAM,
 	DARKNESS_CLOUD,
+    
+	CHASM_WITH_HIDDEN_BRIDGE,
+	CHASM_WITH_HIDDEN_BRIDGE_ACTIVE,
+	MACHINE_CHASM_EDGE,
+    
+    WORM_TUNNEL_MARKER_DORMANT,
+    WORM_TUNNEL_MARKER_ACTIVE,
+    WORM_TUNNEL_OUTER_WALL,
+    
 	NUMBER_TILETYPES,
 	UNFILLED_LAKE = 120	// used to mark lakes not yet assigned a liquid type
 };
@@ -524,6 +558,10 @@ enum lightType {
 	FORCEFIELD_LIGHT,
 	CRYSTAL_WALL_LIGHT,
 	CANDLE_LIGHT,
+    HAUNTED_TORCH_LIGHT,
+    GLYPH_LIGHT_DIM,
+    GLYPH_LIGHT_BRIGHT,
+    DESCENT_LIGHT,
 	NUMBER_LIGHT_KINDS
 };
 
@@ -635,6 +673,7 @@ enum armorEnchants {
 	A_BURDEN,
 	NUMBER_GOOD_ARMOR_ENCHANT_KINDS = A_BURDEN,
 	A_VULNERABILITY,
+    A_IMMOLATION,
 	NUMBER_ARMOR_ENCHANT_KINDS,
 };
 
@@ -761,6 +800,7 @@ enum monsterTypes {
 	MK_UNDERWORM,
 	MK_SENTINEL,
 	MK_ACID_TURRET,
+	MK_DART_TURRET,
 	MK_KRAKEN,
 	MK_LICH,
 	MK_PHYLACTERY,
@@ -781,6 +821,10 @@ enum monsterTypes {
 	
 	MK_SPECTRAL_BLADE,
 	MK_SPECTRAL_IMAGE,
+    MK_GUARDIAN,
+    MK_WINGED_GUARDIAN,
+    MK_ELDRITCH_TOTEM,
+    MK_MIRRORED_TOTEM,
 	
 	MK_UNICORN,
 	MK_IFRIT,
@@ -790,7 +834,7 @@ enum monsterTypes {
 	NUMBER_MONSTER_KINDS
 };
 
-#define	NUMBER_HORDES				149
+#define	NUMBER_HORDES				154
 
 // flavors
 
@@ -855,7 +899,7 @@ enum tileFlags {
 #define MAX_EXP								100000000L
 
 #define XPXP_NEEDED_FOR_ABSORB				4000 // XPXP required for your allies to be eligible to absorb an enemy ability/behavior
-#define XPXP_NEEDED_FOR_LEVELUP				1100 // XPXP required per increase in your allies' stats
+#define XPXP_NEEDED_FOR_LEVELUP				1300 // XPXP required per increase in your allies' stats
 
 #define ROOM_MIN_WIDTH						4
 #define ROOM_MAX_WIDTH						20
@@ -1017,24 +1061,25 @@ boolean cellHasTerrainFlag(short x, short y, unsigned long flagMask);
 #define staffBladeCount(enchant)			((int) ((enchant) * 3 / 2))
 #define staffDiscordDuration(enchant)		((int) ((enchant) * 4))
 #define staffProtection(enchant)			((int) (50 * pow(1.53, (double) (enchant) - 2)))
+#define staffEntrancementDuration(enchant)	((int) (enchant) * 3)
 
 #define wandDominate(monst)					(((monst)->currentHP * 5 < (monst)->info.maxHP) ? 100 : \
 											100 * ((monst)->info.maxHP - (monst)->currentHP) / (monst)->info.maxHP)
 
 #define weaponParalysisDuration(enchant)	(max(2, (int) (2 + (enchant / 2))))
 #define weaponConfusionDuration(enchant)	(max(3, (int) (1.5 * (enchant))))
-#define weaponSlowDuration(enchant)			(max(3, (int) (2 * (enchant))))
+#define weaponSlowDuration(enchant)			(max(3, (int) (((enchant) + 2) * ((enchant) + 2) / 3)))
 #define weaponImageCount(enchant)			(clamp((int) (enchant) / 3, 1, 3))		//(max((int) (((enchant) + 1) / 2), 1))
 #define weaponImageDuration(enchant)		3										//(max((int) (1 + (enchant) / 3), 2))
 
 #define armorReprisalPercent(enchant)		(max(5, (int) (enchant * 5)))
 #define armorAbsorptionMax(enchant)			(max(1, (int) (enchant)))
 #define armorImageCount(enchant)			((int) (clamp((int) (enchant) / 3, 1, 3)))		//(max((int) (((enchant) + 1) / 2), 1))
-#define reflectionChance(enchant)			(100 - (short) (100 * pow(0.85, (enchant))))
+#define reflectionChance(enchant)			(clamp((100 - (short) (100 * pow(0.85, (enchant)))), 1, 100))
 
 #define turnsForFullRegen(bonus)			((long) (1000 * TURNS_FOR_FULL_REGEN * pow(0.75, (bonus)) + 2000))
 											// This will max out at full regeneration in about two turns.
-											// This is the syd nerf, after Syd broke the game over his knee with a +18 ring of regeneration.
+											// This is the Syd nerf, after Syd broke the game over his knee with a +18 ring of regeneration.
 
 // structs
 
@@ -1271,6 +1316,15 @@ enum dungeonFeatureTypes {
 	DF_ALTAR_INERT,
 	DF_ALTAR_RETRACT,
 	DF_PORTAL_ACTIVATE,
+    DF_INACTIVE_GLYPH,
+    DF_ACTIVE_GLYPH,
+    DF_SILENT_GLYPH_GLOW,
+    DF_GUARDIAN_STEP,
+    DF_MIRROR_TOTEM_STEP,
+    DF_GLYPH_CIRCLE,
+    DF_REVEAL_LEVER,
+    DF_PULL_LEVER,
+    DF_CREATE_LEVER,
 	
 	DF_PLAIN_FIRE,
 	DF_GAS_FIRE,
@@ -1289,7 +1343,6 @@ enum dungeonFeatureTypes {
 	DF_HOLE_DRAIN,
 	
 	DF_POISON_GAS_CLOUD,
-	DF_PARALYSIS_GAS_CLOUD,
 	DF_CONFUSION_GAS_TRAP_CLOUD,
 	DF_METHANE_GAS_ARMAGEDDON,
 	
@@ -1301,6 +1354,11 @@ enum dungeonFeatureTypes {
 	DF_DARKNESS_POTION,
 	DF_HOLE_POTION,
 	DF_LICHEN_PLANTED,
+    
+    // other items
+    DF_ARMOR_IMMOLATION,
+    DF_STAFF_HOLE,
+    DF_STAFF_HOLE_EDGE,
 	
 	// vampire in coffin
 	DF_COFFIN_BURSTS,
@@ -1324,7 +1382,7 @@ enum dungeonFeatureTypes {
 	DF_SHALLOW_WATER,
 	DF_WATER_SPREADS,
 	DF_SPREADABLE_WATER_POOL,
-	DF_DEEP_WATER_POOL,
+	DF_SPREADABLE_DEEP_WATER_POOL,
 	
 	// when triggered, the ground gradually turns into chasm:
 	DF_SPREADABLE_COLLAPSE,
@@ -1333,7 +1391,10 @@ enum dungeonFeatureTypes {
 	DF_ADD_MACHINE_COLLAPSE_EDGE_DORMANT,
 	
 	// when triggered, a bridge appears:
+    DF_BRIDGE_ACTIVATE,
+    DF_BRIDGE_ACTIVATE_ANNOUNCE,
 	DF_BRIDGE_APPEARS,
+    DF_ADD_DORMANT_CHASM_HALO,
 	
 	// when triggered, the lava retracts:
 	DF_RETRACTING_LAVA,
@@ -1344,7 +1405,6 @@ enum dungeonFeatureTypes {
 	DF_POISON_GAS_VENT_OPEN,
 	DF_ACTIVATE_PORTCULLIS,
 	DF_OPEN_PORTCULLIS,
-	DF_CLOSE_PORTCULLIS,
 	DF_VENT_SPEW_POISON_GAS,
 	
 	// when triggered, pilot light ignites and explosive gas fills the room
@@ -1352,6 +1412,11 @@ enum dungeonFeatureTypes {
 	DF_METHANE_VENT_OPEN,
 	DF_VENT_SPEW_METHANE,
 	DF_PILOT_LIGHT,
+    
+    // paralysis trap: trigger plate with gas vents nearby
+	DF_DISCOVER_PARALYSIS_VENT,
+	DF_PARALYSIS_VENT_SPEW,
+	DF_REVEAL_PARALYSIS_VENT_SILENTLY,
 	
 	// thematic dungeon
 	DF_AMBIENT_BLOOD,
@@ -1362,10 +1427,18 @@ enum dungeonFeatureTypes {
 	
 	// a turret appears:
 	DF_TURRET_EMERGE,
+    
+    // an elaborate worm catacomb opens up
+    DF_WORM_TUNNEL_MARKER_DORMANT,
+    DF_WORM_TUNNEL_MARKER_ACTIVE,
+    DF_GRANITE_CRUMBLES,
+    DF_WALL_OPEN,
 	
 	// the room gradually darkens
 	DF_DARKENING_FLOOR,
 	DF_DARK_FLOOR,
+    DF_HAUNTED_TORCH_TRANSITION,
+    DF_HAUNTED_TORCH,
 	
 	// bubbles rise from the mud and bog monsters spawn
 	DF_MUD_DORMANT,
@@ -1373,6 +1446,7 @@ enum dungeonFeatureTypes {
 	
 	// idyll:
 	DF_WATER_POOL,
+    DF_DEEP_WATER_POOL,
 	
 	// swamp:
 	DF_SWAMP_WATER,
@@ -1540,6 +1614,7 @@ enum statusEffects {
 	STATUS_DARKNESS,
 	STATUS_LIFESPAN_REMAINING,
 	STATUS_SHIELDED,
+    STATUS_INVISIBLE,
 	NUMBER_OF_STATUS_EFFECTS,
 };
 
@@ -1559,6 +1634,7 @@ enum hordeFlags {
 	HORDE_MACHINE_KENNEL			= Fl(11),	// monsters that can appear in cages in kennels
 	HORDE_VAMPIRE_FODDER			= Fl(12),	// monsters that are prone to capture and farming by vampires
 	HORDE_MACHINE_LEGENDARY_ALLY	= Fl(13),	// legendary allies
+    HORDE_NEVER_OOD                 = Fl(14),   // Horde c
 	
 	HORDE_MACHINE_ONLY				= (HORDE_MACHINE_BOSS | HORDE_MACHINE_WATER_MONSTER
 									   | HORDE_MACHINE_CAPTIVE | HORDE_MACHINE_STATUE
@@ -1592,13 +1668,15 @@ enum monsterBehaviorFlags {
 	MONST_SUBMERGES					= Fl(21),	// monster can submerge in appropriate terrain
 	MONST_MAINTAINS_DISTANCE		= Fl(22),	// monster tries to keep a distance of 3 tiles between it and player
 	MONST_WILL_NOT_USE_STAIRS		= Fl(23),	// monster won't chase the player between levels
-	MONST_DIES_IF_NEGATED			= Fl(24),	// monster is purely magical and will die if subjected to negation magic
+	MONST_DIES_IF_NEGATED			= Fl(24),	// monster will die if exposed to negation magic
 	MONST_MALE						= Fl(25),	// monster is male (or 50% likely to be male if also has MONST_FEMALE)
 	MONST_FEMALE					= Fl(26),	// monster is female (or 50% likely to be female if also has MONST_MALE)
+    MONST_NOT_LISTED_IN_SIDEBAR     = Fl(27),   // monster doesn't show up in the sidebar
+    MONST_GETS_TURN_ON_ACTIVATION   = Fl(28),   // monster never gets a turn, except when its machine is activated
+    MONST_ALWAYS_USE_ABILITY        = Fl(29),   // monster will never fail to use special ability if eligible (no random factor)
 	
 	NEGATABLE_TRAITS				= (MONST_INVISIBLE | MONST_DEFEND_DEGRADE_WEAPON | MONST_IMMUNE_TO_WEAPONS | MONST_FLIES
-									   | MONST_FLITS | MONST_IMMUNE_TO_FIRE | MONST_IMMUNE_TO_WEBS | MONST_FIERY
-									   | MONST_IMMUNE_TO_WATER | MONST_SUBMERGES | MONST_MAINTAINS_DISTANCE),
+									   | MONST_FLITS | MONST_IMMUNE_TO_FIRE | MONST_FIERY | MONST_MAINTAINS_DISTANCE),
 	MONST_TURRET					= (MONST_IMMUNE_TO_WEBS | MONST_NEVER_SLEEPS | MONST_IMMOBILE | MONST_INANIMATE |
 									   MONST_ALWAYS_HUNTING | MONST_ATTACKABLE_THRU_WALLS | MONST_WILL_NOT_USE_STAIRS),
 	LEARNABLE_BEHAVIORS				= (MONST_INVISIBLE | MONST_FLIES | MONST_IMMUNE_TO_FIRE | MONST_REFLECT_4),
@@ -1620,22 +1698,23 @@ enum monsterAbilityFlags {
 	MA_CAST_FIRE					= Fl(11),
 	MA_CAST_SLOW					= Fl(12),
 	MA_CAST_DISCORD					= Fl(13),
-	MA_BREATHES_FIRE				= Fl(14),	// shoots dragonfire at player from a distance
-	MA_SHOOTS_WEBS					= Fl(15),	// monster shoots webs at the player
-	MA_ATTACKS_FROM_DISTANCE		= Fl(16),	// monster shoots from a distance for its attack
-	MA_SEIZES						= Fl(17),	// monster seizes enemies before attacking and cannot attack flying enemies
-	MA_POISONS						= Fl(18),	// monster's damage is dealt in the form of poison, and it flees a poisoned player
-	MA_DF_ON_DEATH					= Fl(19),	// monster spawns its DF when it dies
-	MA_CLONE_SELF_ON_DEFEND			= Fl(20),	// monster splits in two when struck
-	MA_KAMIKAZE						= Fl(21),	// monster dies instead of attacking
-	MA_TRANSFERENCE					= Fl(22),	// monster recovers 90% of the damage that it inflicts as health
-	MA_CAUSES_WEAKNESS				= Fl(23),	// monster attacks cause weakness status in target
+    MA_CAST_BECKONING               = Fl(14),
+	MA_BREATHES_FIRE				= Fl(15),	// shoots dragonfire at player from a distance
+	MA_SHOOTS_WEBS					= Fl(16),	// monster shoots webs at the player
+	MA_ATTACKS_FROM_DISTANCE		= Fl(17),	// monster shoots from a distance for its attack
+	MA_SEIZES						= Fl(18),	// monster seizes enemies before attacking and cannot attack flying enemies
+	MA_POISONS						= Fl(19),	// monster's damage is dealt in the form of poison, and it flees a poisoned player
+	MA_DF_ON_DEATH					= Fl(20),	// monster spawns its DF when it dies
+	MA_CLONE_SELF_ON_DEFEND			= Fl(21),	// monster splits in two when struck
+	MA_KAMIKAZE						= Fl(22),	// monster dies instead of attacking
+	MA_TRANSFERENCE					= Fl(23),	// monster recovers 90% of the damage that it inflicts as health
+	MA_CAUSES_WEAKNESS				= Fl(24),	// monster attacks cause weakness status in target
 	
 	MAGIC_ATTACK					= (MA_CAST_HEAL | MA_CAST_HASTE | MA_CAST_PROTECTION | MA_CAST_NEGATION | MA_CAST_SPARK | MA_CAST_FIRE | MA_CAST_SUMMON
-									   | MA_CAST_SLOW | MA_CAST_DISCORD | MA_BREATHES_FIRE | MA_SHOOTS_WEBS | MA_ATTACKS_FROM_DISTANCE),
+									   | MA_CAST_SLOW | MA_CAST_DISCORD | MA_BREATHES_FIRE | MA_SHOOTS_WEBS | MA_ATTACKS_FROM_DISTANCE | MA_CAST_BECKONING),
 	SPECIAL_HIT						= (MA_HIT_HALLUCINATE | MA_HIT_STEAL_FLEE | MA_HIT_DEGRADE_ARMOR | MA_POISONS | MA_TRANSFERENCE | MA_CAUSES_WEAKNESS),
 	LEARNABLE_ABILITIES				= (MA_CAST_HEAL | MA_CAST_HASTE | MA_CAST_PROTECTION | MA_CAST_BLINK | MA_CAST_NEGATION | MA_CAST_SPARK | MA_CAST_FIRE
-									   | MA_CAST_SLOW | MA_CAST_DISCORD | MA_TRANSFERENCE),
+									   | MA_CAST_SLOW | MA_CAST_DISCORD | MA_TRANSFERENCE | MA_CAUSES_WEAKNESS),
 };
 
 enum monsterBookkeepingFlags {
@@ -1660,6 +1739,7 @@ enum monsterBookkeepingFlags {
 	MONST_IS_DYING					= Fl(18),	// monster has already been killed and is awaiting the end-of-turn graveyard sweep.
 	MONST_GIVEN_UP_ON_SCENT			= Fl(19),	// to help the monster remember that the scent map is a dead end
 	MONST_IS_DORMANT				= Fl(20),	// lurking, waiting to burst out
+    MONST_ALLY_ANNOUNCED_HUNGER     = Fl(21),   // player has gotten the message that the ally is ready to absorb a new power
 };
 
 // Defines all creatures, which include monsters and the player:
@@ -1762,9 +1842,10 @@ typedef struct creature {
 	short status[NUMBER_OF_STATUS_EFFECTS];
 	short maxStatus[NUMBER_OF_STATUS_EFFECTS]; // used to set the max point on the status bars
 	unsigned long bookkeepingFlags;
-	short spawnDepth;					// because monster doesn't earn xpxp on shallower levels than it spawned
+	short spawnDepth;					// because monster doesn't earn xpxp on shallower levels than it spawned, and for activation monsters
+    short machineHome;                  // monsters that spawn in a machine keep track of the machine number here
 	short xpxp;							// exploration experience
-	short absorbsAllowed;				// how many abilities it can absorb
+	short absorbXPXP;                   // absorption experience (accrued like xpxp, but spent on absorbing new powers)
 	struct creature *leader;			// only if monster is a follower
 	struct creature *carriedMonster;	// when vampires turn into bats, one of the bats restores the vampire when it dies
 	struct creature *nextCreature;
@@ -1784,6 +1865,7 @@ enum NGCommands {
 // these are basically global variables pertaining to the game state and player's unique variables:
 typedef struct playerCharacter {
 	short depthLevel;					// which dungeon level are we on
+    short deepestLevel;
 	long foodSpawned;					// amount of nutrition units spawned so far this game
 	boolean disturbed;					// player should stop auto-acting
 	boolean gainedLevel;				// player gained at least one level this turn
@@ -1839,11 +1921,10 @@ typedef struct playerCharacter {
 	creature *lastTarget;				// to keep track of the last monster the player has thrown at or zapped
 	short rewardRoomsGenerated;			// to meter the number of machines
 	short machineNumber;				// so each machine on a level gets a unique number
-	short sidebarLocationList[COLS][2];	// to keep track of which location each line of the sidebar references
+	short sidebarLocationList[ROWS*2][2];	// to keep track of which location each line of the sidebar references
 	
 	// maps
 	short **mapToShore;					// how many steps to get back to shore
-	short **chokepointMap;				// how much territory a chokepoint chokes
 	short **mapToSafeTerrain;			// so monsters can get to safety
 	
 	// recording info
@@ -1937,10 +2018,11 @@ enum machineFeatureFlags {
 	MF_REPEAT_UNTIL_NO_PROGRESS		= Fl(22),	// keep trying to build this feature set until no changes are made
 	MF_IMPREGNABLE					= Fl(23),	// this feature's location will be immune to tunneling
 	MF_IN_VIEW_OF_ORIGIN			= Fl(24),	// this feature must be in view of the origin
-	MF_NOT_IN_HALLWAY				= Fl(25),	// the feature location must have a passableArcCount of <= 1
-	MF_NOT_ON_LEVEL_PERIMETER		= Fl(26),	// don't build it in the outermost walls of the level
-	MF_SKELETON_KEY					= Fl(27),	// if a key is generated or adopted by this feature, it will open all locks in this machine.
-	MF_KEY_DISPOSABLE				= Fl(28),	// if a key is generated or adopted, it will self-destruct after being used at this current location.
+	MF_IN_PASSABLE_VIEW_OF_ORIGIN	= Fl(25),	// this feature must be in view of the origin, where "view" is blocked by pathing blockers
+	MF_NOT_IN_HALLWAY				= Fl(26),	// the feature location must have a passableArcCount of <= 1
+	MF_NOT_ON_LEVEL_PERIMETER		= Fl(27),	// don't build it in the outermost walls of the level
+	MF_SKELETON_KEY					= Fl(28),	// if a key is generated or adopted by this feature, it will open all locks in this machine.
+	MF_KEY_DISPOSABLE				= Fl(29),	// if a key is generated or adopted, it will self-destruct after being used at this current location.
 };
 
 typedef struct machineFeature {
@@ -1974,10 +2056,11 @@ enum blueprintFlags {
 	BP_IMPREGNABLE					= Fl(5),	// impassable perimeter and interior tiles are locked; tunneling bolts will bounce off harmlessly
 	BP_REWARD						= Fl(6),	// metered reward machines
 	BP_OPEN_INTERIOR				= Fl(7),	// clear out walls in the interior, widen the interior until convex or bumps into surrounding areas
-	BP_ROOM							= Fl(8),	// spawns in a dead-end room that is dominated by a chokepoint of the given size (as opposed to a random place of the given size)
-	BP_TREAT_AS_BLOCKING			= Fl(9),	// abort the machine if, were it filled with wall tiles, it would disrupt the level connectivity
-	BP_REQUIRE_BLOCKING				= Fl(10),	// abort the machine unless, were it filled with wall tiles, it would disrupt the level connectivity
-	BP_NO_INTERIOR_FLAG				= Fl(11),	// don't flag the area as being part of a machine
+    BP_MAXIMIZE_INTERIOR            = Fl(8),    // same as BP_OPEN_INTERIOR but expands the room as far as it can go, potentially surrounding the whole level.
+	BP_ROOM							= Fl(9),	// spawns in a dead-end room that is dominated by a chokepoint of the given size (as opposed to a random place of the given size)
+	BP_TREAT_AS_BLOCKING			= Fl(10),	// abort the machine if, were it filled with wall tiles, it would disrupt the level connectivity
+	BP_REQUIRE_BLOCKING				= Fl(11),	// abort the machine unless, were it filled with wall tiles, it would disrupt the level connectivity
+	BP_NO_INTERIOR_FLAG				= Fl(12),	// don't flag the area as being part of a machine
 };
 
 typedef struct blueprint {
@@ -2017,9 +2100,14 @@ enum machineTypes {
 	MT_KEY_EXPLOSIVE_TRAP_ROOM,
 	MT_KEY_BURNING_TRAP_ROOM,
 	MT_KEY_STATUARY_TRAP_AREA,
+    MT_KEY_GUARDIAN_WATER_PUZZLE_ROOM,
+    MT_KEY_GUARDIAN_GAUNTLET_ROOM,
+    MT_KEY_SUMMONING_CIRCLE_ROOM,
+    MT_KEY_BECKONING_OBSTACLE_ROOM,
 	MT_KEY_WORM_TRAP_AREA,
 	MT_KEY_MUD_TRAP_ROOM,
 	MT_KEY_PHANTOM_TRAP_ROOM,
+    MT_KEY_WORM_TUNNEL_ROOM,
 	MT_KEY_TURRET_TRAP_ROOM,
 	MT_KEY_BOSS_ROOM,
 	
@@ -2031,9 +2119,11 @@ enum machineTypes {
 	MT_DISMAL_AREA,
 	MT_BRIDGE_TURRET_AREA,
 	MT_LAKE_PATH_TURRET_AREA,
+    MT_PARALYSIS_TRAP_AREA,
 	MT_TRICK_STATUE_AREA,
 	MT_WORM_AREA,
 	MT_SENTINEL_AREA,
+    MT_GUARDIAN_AREA,
 	
 	NUMBER_BLUEPRINTS,
 };
@@ -2057,7 +2147,7 @@ typedef struct autoGenerator {
 	short maxNumber;
 } autoGenerator;
 
-#define NUMBER_AUTOGENERATORS 31
+#define NUMBER_AUTOGENERATORS 32
 
 #define NUMBER_LEVEL_PROFILES 1
 
@@ -2251,8 +2341,14 @@ extern "C" {
 	void applyColorMultiplier(color *baseColor, color *multiplierColor);
 	void applyColorAverage(color *baseColor, const color *newColor, short averageWeight);
 	void applyColorAugment(color *baseColor, const color *augmentingColor, short augmentWeight);
+    void applyColorScalar(color *baseColor, short scalar);
 	void desaturate(color *baseColor, short weight);
 	void randomizeColor(color *baseColor, short randomizePercent);
+    void irisFadeBetweenBuffers(cellDisplayBuffer fromBuf[COLS][ROWS],
+                                cellDisplayBuffer toBuf[COLS][ROWS],
+                                short x, short y,
+                                short frameCount,
+                                boolean outsideIn);
 	void colorBlendCell(short x, short y, color *hiliteColor, short hiliteStrength);
 	void hiliteCell(short x, short y, const color *hiliteColor, short hiliteStrength, boolean distinctColors);
 	void colorMultiplierFromDungeonLight(short x, short y, color *editColor);
@@ -2443,7 +2539,14 @@ extern "C" {
 	short reflectBolt(short targetX, short targetY, short listOfCoordinates[][2], short kinkCell, boolean retracePath);
 	void checkForMissingKeys(short x, short y);
 	boolean zap(short originLoc[2], short targetLoc[2], enum boltType bolt, short boltLevel, boolean hideDetails);
-	creature *nextTargetAfter(short targetX, short targetY, boolean targetAllies, boolean requireOpenPath);
+	boolean nextTargetAfter(short *returnX,
+                            short *returnY,
+                            short targetX,
+                            short targetY,
+                            boolean targetEnemies,
+                            boolean targetAllies,
+                            boolean targetItems,
+                            boolean requireOpenPath);
 	boolean moveCursor(boolean *targetConfirmed,
 					   boolean *canceled,
 					   boolean *tabKey,
@@ -2486,6 +2589,10 @@ extern "C" {
 								 unsigned long forbiddenMapFlags,
 								 boolean forbidLiquid,
 								 boolean deterministic);
+	boolean getQualifyingGridLocNear(short loc[2],
+									 short x, short y,
+									 boolean grid[DCOLS][DROWS],
+									 boolean deterministic);
 	void demoteMonsterFromLeadership(creature *monst);
 	void toggleMonsterDormancy(creature *monst);
 	void monsterDetails(char buf[], creature *monst);
