@@ -124,7 +124,14 @@ boolean selectFile(char *prompt, char *defaultName, char *suffix) {
 }
 
 void welcome() {
+    char buf[DCOLS*3];
 	message("Hello and welcome, adventurer, to the Dungeons of Doom!", false);
+    strcpy(buf, "Retrieve the ");
+    encodeMessageColor(buf, strlen(buf), &itemMessageColor);
+    strcat(buf, "Amulet of Yendor");
+    encodeMessageColor(buf, strlen(buf), &white);
+    strcat(buf, " from the 26th floor and escape with it!");
+	message(buf, false);
 	messageWithColor("Press <?> for help at any time.", &backgroundMessageColor, false);
 	flavorMessage("The doors to the dungeon slam shut behind you.");
 }
@@ -333,9 +340,9 @@ void initializeRogue(unsigned long seed) {
 	player.ticksUntilTurn = 0;
 	
 	rogue.depthLevel = 1;
+    rogue.deepestLevel = 1;
 	rogue.scentTurnNumber = 1000;
 	rogue.turnNumber = 0;
-	rogue.howManyDepthChanges = 0;
 	rogue.foodSpawned = 0;
 	rogue.gold = 0;
 	rogue.goldGenerated = 0;
@@ -475,9 +482,8 @@ void initializeRogue(unsigned long seed) {
 		theItem = addItemToPack(theItem);
 		
 		theItem = generateItem(STAFF, STAFF_PROTECTION);
-		theItem->enchant1 = 5;
+		theItem->enchant1 = 30;
 		theItem->charges = 300;
-		theItem->flags &= ~ITEM_CURSED;
 		identify(theItem);
 		theItem = addItemToPack(theItem);
 		
@@ -517,15 +523,8 @@ void initializeRogue(unsigned long seed) {
 		identify(theItem);
 		theItem = addItemToPack(theItem);
 		
-		theItem = generateItem(POTION, POTION_TELEPATHY);
-		theItem->quantity = 1;
-		theItem->flags &= ~ITEM_CURSED;
-		identify(theItem);
-		theItem = addItemToPack(theItem);
-		
-		theItem = generateItem(POTION, POTION_DESCENT);
-		theItem->enchant1 = 20;
-		theItem->flags &= ~ITEM_CURSED;
+		theItem = generateItem(POTION, POTION_LEVITATION);
+        theItem->quantity = 2;
 		identify(theItem);
 		theItem = addItemToPack(theItem);
 		
@@ -552,8 +551,8 @@ void updateColors() {
 void startLevel(short oldLevelNumber, short stairDirection) {
 	unsigned long oldSeed;
 	item *theItem;
-	short loc[2], i, j, x, y, px, py, flying;
-	boolean isAlreadyAmulet = false;
+	short loc[2], i, j, x, y, px, py, flying, dir;
+	boolean isAlreadyAmulet = false, placedPlayer;
 	creature *monst;
 	enum dungeonLayers layer;
 	unsigned long timeAway;
@@ -561,15 +560,12 @@ void startLevel(short oldLevelNumber, short stairDirection) {
 	short **mapToPit;
 	boolean connectingStairsDiscovered;
 	
-	rogue.howManyDepthChanges++;
-	
 	rogue.cursorLoc[0] = -1;
 	rogue.cursorLoc[1] = -1;
 	rogue.lastTarget = NULL;
 	
 	if (stairDirection == 0) { // fallen
 		connectingStairsDiscovered = (pmap[rogue.downLoc[0]][rogue.downLoc[1]].flags & (DISCOVERED | MAGIC_MAPPED) ? true : false);
-		
 		levels[oldLevelNumber-1].playerExitedVia[0] = player.xLoc;
 		levels[oldLevelNumber-1].playerExitedVia[1] = player.yLoc;
 	}
@@ -713,6 +709,7 @@ void startLevel(short oldLevelNumber, short stairDirection) {
 		timeAway = max(0, rogue.turnNumber - levels[rogue.depthLevel - 1].awaySince - 1);
 		numberOfRooms = levels[rogue.depthLevel - 1].numberOfRooms;
 		rooms->nextRoom = levels[rogue.depthLevel - 1].roomStorage;
+        levels[rogue.depthLevel - 1].roomStorage = NULL;
 		
 		for (i=0; i<DCOLS; i++) {
 			for (j=0; j<DROWS; j++) {
@@ -789,7 +786,12 @@ void startLevel(short oldLevelNumber, short stairDirection) {
 	player.xLoc = px;
 	player.yLoc = py;
 	
-	levels[rogue.depthLevel-1].visited = true;
+    if (!levels[rogue.depthLevel-1].visited) {
+        levels[rogue.depthLevel-1].visited = true;
+        if (rogue.depthLevel == 26) {
+            messageWithColor("An alien energy permeates the area. The Amulet of Yendor must be nearby!", &itemMessageColor, false);
+        }
+    }
 	
 	// Position the player.
 	if (stairDirection == 0) { // fell into the level
@@ -805,10 +807,21 @@ void startLevel(short oldLevelNumber, short stairDirection) {
 			player.xLoc = rogue.downLoc[0];
 			player.yLoc = rogue.downLoc[1];
 		}
-		
-		getQualifyingLocNear(loc, player.xLoc, player.yLoc, true, 0,
-							 (T_PATHING_BLOCKER),
-							 (HAS_MONSTER | HAS_ITEM | HAS_UP_STAIRS | HAS_DOWN_STAIRS | IS_IN_MACHINE), false, true);
+        
+        placedPlayer = false;
+        for (dir=0; dir<4 && !placedPlayer; dir++) {
+            loc[0] = player.xLoc + nbDirs[dir][0];
+            loc[1] = player.yLoc + nbDirs[dir][1];
+            if (!cellHasTerrainFlag(loc[0], loc[1], T_PATHING_BLOCKER)
+                && !(pmap[loc[0]][loc[1]].flags & (HAS_MONSTER | HAS_ITEM | HAS_UP_STAIRS | HAS_DOWN_STAIRS | IS_IN_MACHINE))) {
+                placedPlayer = true;
+            }
+        }
+		if (!placedPlayer) {
+            getQualifyingLocNear(loc, player.xLoc, player.yLoc, true, 0,
+                                 (T_PATHING_BLOCKER),
+                                 (HAS_MONSTER | HAS_ITEM | HAS_UP_STAIRS | HAS_DOWN_STAIRS | IS_IN_MACHINE), false, true);
+        }
 	}
 	player.xLoc = loc[0];
 	player.yLoc = loc[1];
@@ -816,8 +829,14 @@ void startLevel(short oldLevelNumber, short stairDirection) {
 	pmap[player.xLoc][player.yLoc].flags |= HAS_PLAYER;
 	
 	if (connectingStairsDiscovered) {
-		pmap[rogue.upLoc[0]][rogue.upLoc[1]].flags |= DISCOVERED;
-		rogue.xpxpThisTurn++;
+        for (i = rogue.upLoc[0]-1; i <= rogue.upLoc[0] + 1; i++) {
+            for (j = rogue.upLoc[1]-1; j <= rogue.upLoc[1] + 1; j++) {
+                if (coordinatesAreInMap(i, j)) {
+                    pmap[i][j].flags |= DISCOVERED;
+                    rogue.xpxpThisTurn++;
+                }
+            }
+        }
 	}
 	if (cellHasTerrainFlag(player.xLoc, player.yLoc, T_IS_DEEP_WATER) && !player.status[STATUS_LEVITATING]
 		&& !cellHasTerrainFlag(player.xLoc, player.yLoc, T_ENTANGLES)
@@ -853,7 +872,6 @@ void freeGlobalDynamicGrid(short ***grid) {
 }
 
 void freeCreature(creature *monst) {
-	freeGlobalDynamicGrid(&(monst->mapToMe));
 	freeGlobalDynamicGrid(&(monst->mapToMe));
 	freeGlobalDynamicGrid(&(monst->safetyMap));
 	if (monst->carriedItem) {
@@ -880,16 +898,17 @@ void freeEverything() {
 	short i;
 	creature *monst, *monst2;
 	item *theItem, *theItem2;
+    room *room, *room2;
 	
 #ifdef AUDIT_RNG
 	fclose(RNGLogFile);
 #endif
-	
+    
 	freeGlobalDynamicGrid(&scentMap);
 	freeGlobalDynamicGrid(&safetyMap);
 	freeGlobalDynamicGrid(&allySafetyMap);
-	freeGlobalDynamicGrid(&playerPathingMap);
 	freeGlobalDynamicGrid(&chokeMap);
+	freeGlobalDynamicGrid(&playerPathingMap);
 	freeGlobalDynamicGrid(&rogue.mapToShore);
 	freeGlobalDynamicGrid(&rogue.mapToSafeTerrain);
 	
@@ -906,10 +925,45 @@ void freeEverything() {
 		levels[i].dormantMonsters = NULL;
 		for (theItem = levels[i].items; theItem != NULL; theItem = theItem2) {
 			theItem2 = theItem->nextItem;
-			free(theItem);
+			deleteItem(theItem);
 		}
 		levels[i].items = NULL;
+        for (room = levels[i].roomStorage; room != NULL; room = room2) {
+            room2 = room->nextRoom;
+            free(room);
+        }
+        levels[i].roomStorage = NULL;
 	}
+    for (monst = monsters; monst != NULL; monst = monst2) {
+        monst2 = monst->nextCreature;
+        freeCreature(monst);
+    }
+    monsters = NULL;
+    for (monst = dormantMonsters; monst != NULL; monst = monst2) {
+        monst2 = monst->nextCreature;
+        freeCreature(monst);
+    }
+    dormantMonsters = NULL;
+    for (monst = graveyard; monst != NULL; monst = monst2) {
+        monst2 = monst->nextCreature;
+        freeCreature(monst);
+    }
+    graveyard = NULL;
+    for (theItem = floorItems; theItem != NULL; theItem = theItem2) {
+        theItem2 = theItem->nextItem;
+        deleteItem(theItem);
+    }
+    floorItems = NULL;
+    for (theItem = packItems; theItem != NULL; theItem = theItem2) {
+        theItem2 = theItem->nextItem;
+        deleteItem(theItem);
+    }
+    packItems = NULL;
+    for (room = rooms; room != NULL; room = room2) {
+        room2 = room->nextRoom;
+        free(room);
+    }
+    rooms = NULL;
 }
 
 void gameOver(char *killedBy, boolean useCustomPhrasing) {
@@ -937,6 +991,8 @@ void gameOver(char *killedBy, boolean useCustomPhrasing) {
 		messageWithColor("You die...", &badMessageColor, true);
 		rogue.playbackMode = playback;
 	}
+    
+    rogue.creaturesWillFlashThisTurn = false;
 	
 	if (D_IMMORTAL && !rogue.quit) {
 		message("...but then you get better.", false);
@@ -979,8 +1035,6 @@ void gameOver(char *killedBy, boolean useCustomPhrasing) {
 		displayMoreSign();
 	}
 	
-	rogue.playbackMode = playback;
-	
 	if (!rogue.playbackMode) {
 		if (saveHighScore(theEntry)) {
 			printHighScores(true);
