@@ -23,11 +23,14 @@ static void gameLoop()
 {
 	char font[60];
 	
-	int screenWidth, screenHeight;
 	int fontWidths[13] = {112, 128, 144, 160, 176, 192, 208, 224, 240, 256, 272, 288, 304}; // widths of the font graphics (divide by 16 to get individual character width)
 	int fontHeights[13] = {176, 208, 240, 272, 304, 336, 368, 400, 432, 464, 496, 528, 528}; // heights of the font graphics (divide by 16 to get individual character height)
 
-	TCOD_sys_get_current_resolution(&screenWidth, &screenHeight);
+	const SDL_VideoInfo* vInfo = SDL_GetVideoInfo();
+	int screenWidth = vInfo->current_w;
+	int screenHeight = vInfo->current_h;
+
+
 
 	// adjust for title bars and whatever -- very approximate, but better than the alternative
 	screenWidth -= 6;
@@ -39,6 +42,8 @@ static void gameLoop()
 
 	sprintf(font, "fonts/font-%i.png", brogueFontSize);
 	
+	SDL_WM_SetIcon(SDL_LoadBMP("icon.bmp"), NULL);
+
 	TCOD_console_set_custom_font(font, (TCOD_FONT_TYPE_GREYSCALE | TCOD_FONT_LAYOUT_ASCII_INROW), 0, 0);
 	TCOD_console_init_root(COLS, ROWS, "Brogue", true, renderer); //Fullscreen
 	TCOD_console_map_ascii_codes_to_font(0, 255, 0, 0);
@@ -302,7 +307,7 @@ static boolean tcod_pauseForMilliseconds(short milliseconds)
 }
 
 
-#define PAUSE_BETWEEN_EVENT_POLLING		34//17
+#define PAUSE_BETWEEN_EVENT_POLLING		36//17
 
 static void tcod_nextKeyOrMouseEvent(rogueEvent *returnEvent, boolean textInput, boolean colorsDance)
 {
