@@ -13,6 +13,8 @@ static struct { int curses, color; } videomode = { 0, 0 };
 
 static struct { int width, height; } minsize = { 80, 24 };
 
+static void init_coersion();
+
 static void preparecolor ( ) {
 	static int pairParts[8] = {
 		COLOR_BLACK, COLOR_RED, COLOR_GREEN, COLOR_YELLOW,
@@ -70,7 +72,9 @@ static int curses_init( ) {
 
 
 static int term_start() {
-	return curses_init();
+	int ok = curses_init();
+	init_coersion();
+	return ok;
 }
 
 static void term_end() {
@@ -118,6 +122,8 @@ CIE ciePalette[16];
 Lab labPalette[16];
 CIE adamsPalette[16];
 
+static CIE white;
+
 static CIE toCIE(fcolor c) {
 	double a = 0.055;
 
@@ -145,8 +151,6 @@ static float Labf(float t) {
 	return t > ((6.0/29.0) * (6.0/29.0) * (6.0/29.0)) ? pow(t, 1.0/3.0) : ((1.0/3.0) * (29.0 / 6.0) * (29.0 / 6.0)) * t + (4.0 / 29.0);
 }
 
-static CIE white;
-
 static Lab toLab(CIE *c) {
 	CIE n = (CIE) {Labf(c->X / white.X), Labf(c->Y / white.Y), Labf(c->Z / white.Z)};
 	Lab l;
@@ -191,59 +195,76 @@ static float adamsDistance(CIE *v1, CIE *v2) {
 	return sqrt(SQUARE(v2->X - v1->X) + SQUARE(v2->Y - v1->Y) + SQUARE(v2->Z - v1->Z));
 }
 
+static void init_coersion() {
+	fcolor sRGB_white = (fcolor) {1, 1, 1};
+	white = toCIE(sRGB_white);
+
+	int i;
+	for (i = 0; i < 16; i++) {
+		ciePalette[i] = toCIE(palette[i]);
+		labPalette[i] = toLab(&ciePalette[i]);
+		adamsPalette[i] = adams(&ciePalette[i]);
+	}
+}
+
 static int best (fcolor *fg, fcolor *bg) {
 	// analyze fg & bg for their contrast
 	CIE cieFg = toCIE(*fg);
 	CIE cieBg = toCIE(*bg);
 	Lab labFg = toLab(&cieFg);
 	Lab labBg = toLab(&cieBg);
-	CIE adamsFg = adams(&cieFg);
-	CIE adamsBg = adams(&cieBg);
+	// CIE adamsFg = adams(&cieFg);
+	// CIE adamsBg = adams(&cieBg);
 	
 	float JND = 2.3; // just-noticeable-difference
 	int areTheSame = CIE76(&labFg, &labBg) <= 2.0 * JND; // a little extra fudge
-	int bestpair = 0;
-	float bestrating = 10000.0;
 
-	fcolor sRGB_white = (fcolor) {1, 1, 1};
-	white = toCIE(sRGB_white);
-	int i, j;
+	float big = 100000000;
+	int fg1 = 0, fg2 = 0, bg1 = 0, bg2 = 0;
+	float fg1_score = big, fg2_score = big;
+	float bg1_score = big, bg2_score = big;
 
-	for (i = 0; i < 16; i++) {
-		ciePalette[i] = toCIE(palette[i]);
-		labPalette[i] = toLab(&ciePalette[i]);
-		adamsPalette[i] = adams(&ciePalette[i]);
-	}
-
-	float fgscore[16], bgscore[16];
-
-	for (i = 0; i < 16; i++) {
-		fgscore[i] = 0.0;
-		fgscore[i] += CIE76(labPalette + i, &labFg);
-		//fgscore[i] += CIExyY(ciePalette + i, &cieFg);
-		//fgscore[i] += 50 * adamsDistance(adamsPalette + i, &adamsFg);
-
-		bgscore[i] = 0.0;
-		bgscore[i] += CIE76(labPalette + i, &labBg);
-		//bgscore[i] += CIExyY(ciePalette + i, &cieBg);
-		//bgscore[i] += 50 * adamsDistance(adamsPalette + i, &adamsBg);
-	}
+	int i;
 
 	for (i = 0; i < 8; i++) {
-		for (j = 0; j < 16; j++) {
-			if ((i == j && !areTheSame)) continue;
-			// if (j == 8) continue; // for terms with no bright black
+		float s = CIE76(labPalette + i, &labBg);
 
-			// float rating = closeness(ciePalette + i, &cieBg) + closeness(ciePalette + j, &cieFg);
-			float rating = fgscore[j] + bgscore[i];
-
-			if (rating < bestrating) {
-				bestpair = COLORING(j, i);
-				bestrating = rating;
+		if (s < bg2_score) {
+			if (s < bg1_score) {
+				bg2 = bg1; bg1 = i;
+				bg2_score = bg1_score; bg1_score = s;
+			} else {
+				bg2 = i; bg2_score = s;
 			}
 		}
 	}
-	return bestpair;
+
+	if (areTheSame) {
+		return COLORING(bg1, bg1);
+	}
+
+	for (i = 0; i < 16; i++) {
+		float s = CIE76(labPalette + i, &labFg);
+
+		if (s < fg2_score) {
+			if (s < fg1_score) {
+				fg2 = fg1; fg1 = i;
+				fg2_score = fg1_score; fg1_score = s;
+			} else {
+				fg2 = i; fg2_score = s;
+			}
+		}
+	}
+
+	if (fg1 != bg1) {
+		return COLORING (fg1, bg1);
+	} else {
+		if (fg1_score + bg2_score < fg2_score + bg1_score) {
+			return COLORING(fg1, bg2);
+		} else {
+			return COLORING(fg2, bg1);
+		}
+	}
 }
 
 static int coerce (fcolor *color, float dark, float saturation, float brightcut, float grey) {
@@ -372,7 +393,7 @@ static void ensure_size( ) {
 			attrset(COLOR_ATTR(7));
 			mvprintw(3,0,"Press ctrl-c at any time to quit.\n");
 #ifdef BROGUE_TCOD
-			mvprintw(5,0,"To use libtcod, start the game with the -gl or -s.\n\n");
+			mvprintw(5,0,"To use libtcod, start the game with the -gl or --SDL.\n\n");
 #endif
 
 			printw("Width:  %d/%d\n", Term.width, w);
